@@ -8,5 +8,5 @@ class Entry(kii.stream.models.StreamItem):
 
     slug = kii.base_models.fields.SlugField(populate_from=("title",))
 
-    def reverse_detail(self, **kwargs):
-        return reverse("kii:user_area:blog:entry:detail", kwargs={"slug":self.slug, "username": self.owner.username})
+    # def reverse_custom_detail(self, **kwargs):
+    #     return reverse("kii:user_area:blog:entry:detail", kwargs={"slug":self.slug, "username": self.owner.username})
