@@ -3,6 +3,6 @@ from kii.stream import views
 from . import models
 
 
-class EntryList(views.Index):
+class EntryList(views.List):
     streamitem_class = models.Entry
 
